# Auto Forecast
AutoML library for time series forecasting

## Getting started

Install virtualenv
```bash
$ pip install virtualenv
```

Create a virtualenv named venv
```bash
$ virtualenv venv
```

Activate the virtualenv venv
```bash
$ source venv/bin/activate
```

Upgrade pip
```bash
$ pip install pip --upgrade
```

Install the requirements
```bash
$ pip install -r requirements.txt
```

Run the main.py file
```bash
$ python3 main.py
```
